/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import net.sourceforge.writexml.Attributes;
import net.sourceforge.writexml.TagName;

import static net.sourceforge.writexml.Attribute.attribute;
import static net.sourceforge.writexml.AttributeName.attributeName;
import static net.sourceforge.writexml.AttributeValue.attributeValue;


abstract class FormElementTag<T extends StandardXhtmlTag<T, XhtmlTag>> extends StandardXhtmlTag<T, XhtmlTag> implements BodyElement<DoesNotContainFormTag, TagScope.InlineExceptAnchor> {
    public FormElementTag(final TagName tagName, final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(tagName, attributes, children);
    }

    public final T disabled() {
        return makeANewOne(attribute(attributeName("disabled"), attributeValue(new Disabled().asString()), NAMESPACE));
    }

    public final T withOnChange(final EventHandler onChange) {
        return makeANewOne(attribute(attributeName("onchange"), attributeValue(onChange.asString()), NAMESPACE));
    }

    public final T withOnFocus(final EventHandler onFocus) {
        return makeANewOne(attribute(attributeName("onfocus"), attributeValue(onFocus.asString()), NAMESPACE));
    }

    public final T withOnBlur(final EventHandler eventHandler) {
        return makeANewOne(attribute(attributeName("onblur"), attributeValue(eventHandler.asString()), NAMESPACE));
    }

    public final T withName(final InputName inputName) {
        return makeANewOne(attribute(attributeName("name"), attributeValue(inputName.asString()), NAMESPACE));
    }

    public final T withTabIndex(final TabIndex tabIndex) {
        return makeANewOne(attribute(attributeName("tabindex"), attributeValue(tabIndex.asString()), NAMESPACE));
    }

}
