/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import net.sourceforge.writexml.Attribute;
import net.sourceforge.writexml.AttributeName;
import net.sourceforge.writexml.Attributes;

import java.util.Collections;

import static java.util.Arrays.asList;
import static net.sourceforge.writexml.Attributes.attributes;
import static net.sourceforge.writexml.TagName.tagName;
import static net.sourceforge.xazzle.xhtml.Relationships.relationships;

public final class LinkTag extends StandardXhtmlTag<LinkTag, XhtmlTag> implements HeadChild {

    private LinkTag(final Attributes attributes) {
        super(tagName("link"), attributes, Collections.<XhtmlTag>emptyList());
    }

    static LinkTag linkTag() {
        return new LinkTag(attributes());
    }

    @Override
    LinkTag makeANewOne(final Attribute attribute) {
        return new LinkTag(attributes.append(attribute));
    }

    public LinkTag withCharacterSet(final CharacterSet characterSet) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("charset"), net.sourceforge.writexml.AttributeValue.attributeValue(characterSet.asString()), NAMESPACE));
    }

    public LinkTag withHref(final Href href) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("href"), net.sourceforge.writexml.AttributeValue.attributeValue(href.asString()), NAMESPACE));
    }

    public LinkTag withHrefLanguage(final LanguageCode languageCode) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("hreflang"), net.sourceforge.writexml.AttributeValue.attributeValue(languageCode.asString()), NAMESPACE));
    }

    public LinkTag withMedia(final Medium medium, final Medium... media) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("media"), net.sourceforge.writexml.AttributeValue.attributeValue(new Media(medium, asList(media)).asString()), NAMESPACE));
    }

    public LinkTag withMedia(final Medium medium, final Iterable<Medium> media) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("media"), net.sourceforge.writexml.AttributeValue.attributeValue(new Media(medium, media).asString()), NAMESPACE));
    }

    public LinkTag withRelationships(final Relationships relationships) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("rel"), net.sourceforge.writexml.AttributeValue.attributeValue(relationships.asString()), NAMESPACE));
    }

    public LinkTag withRelationships(final Relationship relationship, final Relationship... relationships) {
        return withRelationships(relationships(relationship, relationships));
    }

    public LinkTag withReverseLinks(final Relationships relationships) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("rev"), net.sourceforge.writexml.AttributeValue.attributeValue(relationships.asString()), NAMESPACE));
    }

    public LinkTag withMimeType(final MimeType mimeType) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("type"), net.sourceforge.writexml.AttributeValue.attributeValue(mimeType.asString()), NAMESPACE));
    }
}
