/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import net.sourceforge.writexml.Attribute;
import net.sourceforge.writexml.Attributes;
import net.sourceforge.writexml.TagName;

import static java.util.Arrays.asList;
import static net.sourceforge.writexml.Attribute.attribute;
import static net.sourceforge.writexml.AttributeName.attributeName;
import static net.sourceforge.writexml.AttributeValue.attributeValue;
import static net.sourceforge.writexml.Attributes.attributes;
import static net.sourceforge.writexml.TagName.tagName;

public final class SelectTag extends FormElementTag<SelectTag> {

    static SelectTag selectTag(final SelectTagElement selectTagElement, final SelectTagElement... selectTagElements) {
        return new SelectTag(tagName("select"), attributes(), IterableUtils.cons(selectTagElement, asList(selectTagElements)));
    }

    static SelectTag selectTag(final SelectTagElement selectTagElement, final Iterable<SelectTagElement> selectTagElements) {
        return new SelectTag(tagName("select"), attributes(), IterableUtils.cons(selectTagElement, selectTagElements));
    }

    private SelectTag(final TagName tagName, final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(tagName, attributes, children);
    }

    @Override
    SelectTag makeANewOne(final Attribute attribute) {
        return new SelectTag(tagName, attributes.append(attribute), children);
    }

    public SelectTag allowMultipleSelections() {
        return makeANewOne(attribute(attributeName("multiple"), attributeValue(new MultipleSelections().asString()), NAMESPACE));
    }

    public SelectTag withSize(final Size size) {
        return makeANewOne(attribute(attributeName("size"), attributeValue(size.asString()), NAMESPACE));
    }
}
