/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import net.sourceforge.writexml.Attribute;
import net.sourceforge.writexml.AttributeName;
import net.sourceforge.writexml.Attributes;
import net.sourceforge.writexml.Namespace;

import java.util.Collections;
import java.util.List;

import static java.util.Arrays.asList;
import static net.sourceforge.writexml.Attributes.attributes;
import static net.sourceforge.writexml.TagName.tagName;

public final class StyleTag extends BasicXhtmlTag<StyleTag, XhtmlTag> implements HeadChild {

    private static final Attribute PRESERVE_SPACE = Attribute.attribute(AttributeName.attributeName("space"), net.sourceforge.writexml.AttributeValue.attributeValue(new AttributeValue() {
        public String asString() {
            return "preserve";
        }
    }.asString()), Namespace.XML);

    static StyleTag styleTag(final MimeType mimeType) {
        return styleTag(mimeType, Collections.<XhtmlTag>emptyList());
    }

    static StyleTag styleTag(final MimeType mimeType, final TextElement textElement) {
        return styleTag(mimeType, asList(textElement));
    }

    private static StyleTag styleTag(final MimeType mimeType, final List<? extends XhtmlTag> children) {
        return new StyleTag(attributes(
                Attribute.attribute(AttributeName.attributeName("type"), net.sourceforge.writexml.AttributeValue.attributeValue(mimeType.asString()), NAMESPACE)
        ), children);
    }

    private StyleTag(final Attributes attributes, final List<? extends XhtmlTag> children) {
        super(tagName("style"), attributes, children);
    }

    @Override
    StyleTag makeANewOne(final Attribute attribute) {
        return new StyleTag(attributes.append(attribute), Collections.<XhtmlTag>emptyList());
    }

    public StyleTag preserveSpace() {
        return makeANewOne(PRESERVE_SPACE);
    }

    public StyleTag withTitle(final Title title) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("title"), net.sourceforge.writexml.AttributeValue.attributeValue(title.asString()), NAMESPACE));
    }

    public StyleTag withMedia(final Medium medium, final Medium... media) {
        return withMedia(medium, asList(media));
    }

    public StyleTag withMedia(final Medium medium, final Iterable<Medium> media) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("media"), net.sourceforge.writexml.AttributeValue.attributeValue(new Media(medium, media).asString()), NAMESPACE));
    }
}
