/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import net.sourceforge.writexml.Attributes;
import net.sourceforge.writexml.TagName;

import static net.sourceforge.writexml.Attribute.attribute;
import static net.sourceforge.writexml.AttributeName.attributeName;
import static net.sourceforge.writexml.AttributeValue.attributeValue;


public abstract class TableContentTag<T extends TableContentTag<T>> extends StandardXhtmlTag<T, XhtmlTag> {
    TableContentTag(final TagName tagName, final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(tagName, attributes, children);
    }

    public final T withHorizontalAlignment(final HorizontalAlignment alignment) {
        return makeANewOne(attribute(attributeName("align"), attributeValue(alignment.asString()), NAMESPACE));
    }

    public final T withChar(final AlignmentCharacter alignmentCharacter) {
        return makeANewOne(attribute(attributeName("char"), attributeValue(alignmentCharacter.asString()), NAMESPACE));
    }

    public final T withCharOffset(final AlignmentCharacterOffset alignmentCharacterOffset) {
        return makeANewOne(attribute(attributeName("charoff"), attributeValue(alignmentCharacterOffset.asString()), NAMESPACE));
    }

    public final T withVerticalAlignment(final VerticalAlignment verticalAlignment) {
        return makeANewOne(attribute(attributeName("valign"), attributeValue(verticalAlignment.asString()), NAMESPACE));
    }
}
