/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import net.sourceforge.writexml.Attribute;
import net.sourceforge.writexml.Attributes;
import net.sourceforge.writexml.TagName;

import static java.util.Arrays.asList;
import static net.sourceforge.writexml.Attributes.attributes;
import static net.sourceforge.writexml.TagName.tagName;
import static net.sourceforge.xazzle.xhtml.IterableUtils.cons;

public final class TableFooterTag<T extends MayContainFormTag> extends TableContentTag<TableFooterTag<T>> {

    private TableFooterTag(final TagName tagName, final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(tagName, attributes, children);
    }

    static <T extends MayContainFormTag> TableFooterTag<T> tableFooterTag(final TableRowTag<? extends T> child, final TableRowTag<? extends T>... children) {
        return new TableFooterTag<>(tagName("tfoot"), attributes(), cons(child, asList(children)));
    }

    @Override
    TableFooterTag<T> makeANewOne(final Attribute attribute) {
        return new TableFooterTag<>(tagName, attributes.append(attribute), children);
    }
}
